Installation
============

Requirements
------------

Python 3.8 to 3.12 supported. 

Currently it builds the non-EOL python versions with `maturin <https://github.com/PyO3/maturin>`_ github-actions.


Installation
------------

1. Install with **pip**:

   .. code-block:: python

       python -m pip install resvg_py
